var createError = require('http-errors');
var express = require('express');
var path = require('path');
var cookieParser = require('cookie-parser');
var logger = require('morgan');
const http = require('http');

const hostname = 'petrov.nexus';
const httpPort = 4080;

var mongoose = require('mongoose');
var mongoDB = "mongodb://127.0.0.1/my_database";
mongoose.connect(mongoDB);
mongoose.set('strictQuery', false);
mongoose.Promise = global.Promise;
var db = mongoose.connection;
db.on('error', console.error.bind(console, 'MongoDB connection error:'));


var app = express();

const httpServer = http.createServer(app);

// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'hbs');

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, 'public')));

var mainRouter = require('./routes/main');
var apiRouter = require('./routes/api/apiRouter');

app.use('/', mainRouter);
app.use('/api', apiRouter);

// catch 404 and forward to error handler
app.use(function (req, res, next) {
  next(createError(404));
});

// error handler
app.use(function (err, req, res, next) {
  // set locals, only providing error in development
  res.locals.message = err.message;
  res.locals.error = req.app.get('env') === 'development' ? err : {};

  // render the error page
  res.status(err.status || 500);
  res.render('error', { title: 'Error' });
});

httpServer.listen(httpPort, () => {
  console.log(`Server running at http://${hostname}:${httpPort}/`);
});

module.exports = app;